@@ -48,8 +48,10 @@ This module contains constants, numerical approximations, and unit conversions
    to_meters
 
 """
+from __future__ import annotations
+
 from numbers import Number
-from typing import Sequence, Union
+from typing import Literal, Sequence, Union, get_args
 
 import numpy as np
 from scipy.constants import c, inch, mil
@@ -103,12 +105,24 @@ Minimum eigenvalue used in :meth:`~skrf.mathFunctions.nudge_eig`
 """
 
 # S-parameter definition labels and default definition
-S_DEFINITIONS = ['power', 'pseudo', 'traveling']
+SdefT = Literal["power", "pseudo", "traveling"]
+S_DEFINITIONS: list[SdefT] = list(get_args(SdefT))
 S_DEF_DEFAULT = 'power'
 S_DEF_HFSS_DEFAULT = 'traveling'
 
+FrequencyUnitT = Literal["Hz", "kHz", "MHz", "GHz", "THz"]
 FREQ_UNITS = {"Hz": 1.0, "kHz": 1e3, "MHz": 1e6, "GHz": 1e9, "THz": 1e12}
 
+SweepTypeT = Literal["lin", "log"]
+CoordT = Literal["cart", "polar"]
+InterpolKindT = Literal["linear", "cubic", "nearest", "zero", "slinear", "quadratic", "rational"]
+PrimaryPropertiesT = Literal['s', 'z', 'y', 'a', 'h', 't']
+ComponentFuncT = Literal["re", "im", "mag", "db", "db10", "rad", "deg", "arcl", "rad_unwrap", "deg_unwrap",
+                         "arcl_unwrap", "vswr", "time", "time_db", "time_mag", "time_impulse", "time_step"]
+SparamFormatT = Literal["db", "ri", "ma"]
+PortOrderT = Literal["first", "second", "third", "last", "auto"]
+CircuitComponentT = Literal["_is_circuit_port", "_is_circuit_ground", "_is_circuit_open"]
+
 NumberLike = Union[Number, Sequence[Number], np.ndarray]
 
 global distance_dict
