@@ -75,7 +75,7 @@ class NetworkTestCase(unittest.TestCase):
 
     def test_network_copy(self):
         n = self.ntwk1
-        n._ext_attrs['_test_attr'] = 'test'
+        n._ext_attrs['_is_circuit_port'] = True
         n2 = n.copy()
         self.assertEqual( n.frequency, n2.frequency)
         self.assertNotEqual( id(n.frequency), id(n2.frequency))
@@ -84,7 +84,7 @@ class NetworkTestCase(unittest.TestCase):
         n.frequency.f[0] = 0
         self.assertNotEqual(n2.frequency.f[0], 0)
 
-        self.assertEqual('test', n2._ext_attrs.get('_test_attr', None))
+        self.assertEqual(True, n2._ext_attrs.get('_is_circuit_port', False))
 
     def test_two_port_reflect(self):
         number_of_data_points = 10
@@ -464,23 +464,38 @@ class NetworkTestCase(unittest.TestCase):
     def test_write_touchstone_noisy(self):
         ntwk = self.ntwk_noise
 
-        # Read back the written touchstone
-        ntwkstr = ntwk.write_touchstone(return_string=True)
-        strio = io.StringIO(ntwkstr)
-        strio.name = 'StringIO.s2p'
-        new_ntwk = rf.Network(strio)
+        # Test with and without noise data formatting
+        for use_formatting in (False, True):
+            # Read back the written touchstone
+            if use_formatting:
+                ntwkstr = ntwk.write_touchstone(
+                    return_string=True,
+                    format_spec_freq='{:<6.4f}',
+                    format_spec_A='\t{:>6.4f}',
+                    format_spec_B='\t{:>6.4f}',
+                    format_spec_nf_freq='{:<6.4f}',
+                    format_spec_nf_min='\t{:<6.4f}',
+                    format_spec_g_opt_mag='\t{:<6.4f}',
+                    format_spec_g_opt_phase='\t{:<6.4f}',
+                    format_spec_rn='\t{:<6.4f}',
+                )
+            else:
+                ntwkstr = ntwk.write_touchstone(return_string=True)
+            strio = io.StringIO(ntwkstr)
+            strio.name = 'StringIO.s2p'
+            new_ntwk = rf.Network(strio)
 
-        # Only compare to original noise data, not interpolated
-        ntwk.resample(ntwk.f_noise)
-        new_ntwk.resample(new_ntwk.f_noise)
+            # Only compare to original noise data, not interpolated
+            ntwk.resample(ntwk.f_noise)
+            new_ntwk.resample(new_ntwk.f_noise)
 
-        # Newly written noise properties should match the original
-        np.testing.assert_allclose(ntwk.f_noise.f_scaled, new_ntwk.f_noise.f_scaled)
-        np.testing.assert_allclose(ntwk.nfmin, new_ntwk.nfmin)
-        np.testing.assert_allclose(ntwk.nfmin_db, new_ntwk.nfmin_db)
-        np.testing.assert_allclose(ntwk.g_opt, new_ntwk.g_opt)
-        np.testing.assert_allclose(ntwk.rn, new_ntwk.rn)
-        np.testing.assert_allclose(ntwk.z0, new_ntwk.z0)
+            # Newly written noise properties should match the original
+            np.testing.assert_allclose(ntwk.f_noise.f_scaled, new_ntwk.f_noise.f_scaled)
+            np.testing.assert_allclose(ntwk.nfmin, new_ntwk.nfmin)
+            np.testing.assert_allclose(ntwk.nfmin_db, new_ntwk.nfmin_db)
+            np.testing.assert_allclose(ntwk.g_opt, new_ntwk.g_opt)
+            np.testing.assert_allclose(ntwk.rn, new_ntwk.rn)
+            np.testing.assert_allclose(ntwk.z0, new_ntwk.z0)
 
     def test_pickling(self):
         original_ntwk = self.ntwk1
@@ -650,6 +665,22 @@ class NetworkTestCase(unittest.TestCase):
                 np.testing.assert_almost_equal(net12.s, net3_ref.s)
                 np.testing.assert_almost_equal(net3_z, net3_ref.z)
 
+    def test_connect_drop_ext_attrs(self):
+        """Test that connecting a network created using the Circuit's class
+        method, which has '_ext_attr' attributes, to another standard network.
+        """
+        # Create a network with '_ext_attr' attributes
+        ntwk_tmp = self.ntwk1.copy()
+        ntwk_tmp._ext_attrs['_is_circuit_open'] = True
+
+        # Connect the network to another standard network
+        ntwk_connected = rf.connect(ntwk_tmp, 1, self.ntwk2, 0)
+        self.assertFalse(ntwk_connected._ext_attrs.get('_is_circuit_open', False))
+
+        # Connect the network to another standard network
+        ntwk_connected = rf.connect(self.ntwk2, 0, ntwk_tmp, 1)
+        self.assertFalse(ntwk_connected._ext_attrs.get('_is_circuit_open', False))
+
     def test_interconnect_complex_ports(self):
         """ Test that connecting two complex ports in a network
         gives the same S-parameters with all s_def when the rest of
@@ -1601,6 +1632,41 @@ class NetworkTestCase(unittest.TestCase):
             self.assertTrue(abs(nfmin_set - nfmin_rb) < 1.e-2, 'nf not retrieved by noise deembed')
             self.assertTrue(abs(gamma_opt_rb.s[0,0,0] - gamma_opt_set) < 1.e-1, 'nf not retrieved by noise deembed')
 
+    def test_noise_interpolation(self):
+
+        # Get a handle for the test network. Note that the s-parameter frequency range is beyond that of the NF data
+        ntwk = rf.Network(os.path.join(self.test_dir,'ntwk_noise_interp.s2p'))
+
+        # Pulling out the noise data should interpolate and fill extrapolated values with the default np.nan
+        self.assertIn(True, np.isnan(ntwk.copy().n))
+
+        # Check that a particular fill value is NOT in the noise data
+        fill_val = 12345 + 1j * 67890
+        new_ntwk = ntwk.copy()
+        self.assertNotIn(fill_val, new_ntwk.n)
+
+        # Change the interpolation fill value and check if it filled in properly
+        new_ntwk = ntwk.copy()
+        new_ntwk.noise_fill_value = fill_val
+        self.assertIn(fill_val, new_ntwk.n)
+
+    def test_spar_interpolation(self):
+
+        # Create new frequency vectors beyond the original limits of ntwk1
+        new_freqs_low = rf.Frequency.from_f(self.ntwk1.f / 2, unit="Hz")
+        new_freqs_high = rf.Frequency.from_f(self.ntwk1.f * 2, unit="Hz")
+
+        # Test that no kwargs results in ValueErrors
+        for new_f in (new_freqs_low, new_freqs_high):
+            new_ntwk = self.ntwk1.copy()
+            with self.assertRaises(ValueError) as context:
+                new_ntwk.resample(new_f)
+
+        # Test that kwargs can let the resampling work
+        for new_f in (new_freqs_low, new_freqs_high):
+            new_ntwk = self.ntwk1.copy()
+            new_ntwk.resample(new_f, bounds_error=False)
+            self.assertIn(True, np.isnan(new_ntwk.s))
 
     def test_se2gmm2se(self):
         # Test that se2gmm followed by gmm2se gives back the original network
@@ -2021,9 +2087,16 @@ class NetworkTestCase(unittest.TestCase):
             self.ntwk1.nf_circle(nf=1.0, npoints=0)
 
         # Check whether the specified noise figure is too small.
-        with pytest.raises(RuntimeWarning):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter("always")
             self.ntwk_noise['1GHz'].nf_circle(nf=0.1)
 
+            # Check that a warning was raised
+            assert len(w) > 0, "Expected a warning to be raised"
+
+            # Check that the warning is a RuntimeWarning
+            assert any(item.category is RuntimeWarning for item in w), "Expected RuntimeWarning was not raised"
+
     def test_de_embed_by_floordiv(self):
         ntwk_result_1 = self.ntwk1 // self.ntwk2
         ntwk_result_2 = self.ntwk1 // (self.ntwk2)
