@@ -2,6 +2,7 @@ import glob
 import os
 import sys
 import unittest
+from pathlib import Path
 
 import numpy as np
 import pytest
@@ -226,6 +227,8 @@ class NetworkSetTestCase(unittest.TestCase):
         os.remove('testing.xlsx')
         # passing a filename
         ns.write_spreadsheet(file_name='testing2.xlsx')
+        # Using pathlib
+        ns.write_spreadsheet(file_name=Path('testing2.xlsx'))
         os.remove('testing2.xlsx')
 
     def test_ntwk_attr_2_df(self):
@@ -323,7 +326,6 @@ class NetworkSetTestCase(unittest.TestCase):
         self.assertEqual(len(self.ns_params.sel({'a': [0,1]})), 4)
         self.assertEqual(len(self.ns_params.sel({'a': range(0,2)})), 4)
         # Multiple parameters
-        self.assertEqual(len(self.ns_params.sel({'a': 0, 'X': 10})), 1)
         self.assertEqual(len(self.ns_params.sel({'a': 0, 'X': [10,20]})), 2)
         self.assertEqual(len(self.ns_params.sel({'a': [0,1], 'X': [10,20]})), 4)
 
@@ -370,38 +372,67 @@ class NetworkSetTestCase(unittest.TestCase):
             print(mdif_file)
             self.assertIsInstance(rf.NetworkSet.from_mdif(mdif_file), rf.NetworkSet)
 
+            # With Path objects
+            self.assertIsInstance(rf.NetworkSet.from_mdif(Path(mdif_file)), rf.NetworkSet)
+
     def test_to_mdif(self):
         """ Test is NetworkSet are equal after writing and reading to MDIF """
         test_file = '_test.mdif'
 
-        # without parameters
-        self.ns.write_mdif(test_file)
-        ns = rf.NetworkSet.from_mdif(test_file)
-        self.assertEqual(ns, self.ns)
+        # With and without Path objects
+        for func in (str, Path):
 
-        # with parameters but without passing explicitly the values
-        self.ns_params.write_mdif(test_file)
-        ns_params = rf.NetworkSet.from_mdif(test_file)
-        self.assertEqual(ns_params, self.ns_params)
+            # without parameters
+            self.ns.write_mdif(func(test_file))
+            ns = rf.NetworkSet.from_mdif(func(test_file))
+            self.assertEqual(ns, self.ns)
 
-        # with parameters and passing explicitly values but not types
-        self.ns_params.write_mdif(test_file,
-                                  values=self.ns_params.params_values)
-        ns_params = rf.NetworkSet.from_mdif(test_file)
-        self.assertEqual(ns_params, self.ns_params)
+            # with parameters but without passing explicitly the values
+            self.ns_params.write_mdif(func(test_file))
+            ns_params = rf.NetworkSet.from_mdif(func(test_file))
+            self.assertEqual(ns_params, self.ns_params)
 
-        # with parameters and passing explicitly types but not values
-        self.ns_params.write_mdif(test_file,
-                                  data_types=self.ns_params.params_types)
-        ns_params = rf.NetworkSet.from_mdif(test_file)
-        self.assertEqual(ns_params, self.ns_params)
+            # with parameters and passing explicitly values but not types
+            self.ns_params.write_mdif(func(test_file),
+                                      values=self.ns_params.params_values)
+            ns_params = rf.NetworkSet.from_mdif(func(test_file))
+            self.assertEqual(ns_params, self.ns_params)
+
+            # with parameters and passing explicitly types but not values
+            self.ns_params.write_mdif(func(test_file),
+                                      data_types=self.ns_params.params_types)
+            ns_params = rf.NetworkSet.from_mdif(func(test_file))
+            self.assertEqual(ns_params, self.ns_params)
+
+            # with parameters and passing explicitly values and types
+            self.ns_params.write_mdif(func(test_file),
+                                      values=self.ns_params.params_values,
+                                      data_types=self.ns_params.params_types)
+            ns_params = rf.NetworkSet.from_mdif(func(test_file))
+            self.assertEqual(ns_params, self.ns_params)
+
+            # with parameters and passing explicitly values but not types and ads_compatible
+            self.ns_params.write_mdif(func(test_file),
+                                      values=self.ns_params.params_values,
+                                      ads_compatible=True)
+            ns_params = rf.NetworkSet.from_mdif(func(test_file))
+            self.assertEqual(ns_params, self.ns_params)
+
+            # with parameters and passing explicitly types but not values and ads_compatible
+            self.ns_params.write_mdif(func(test_file),
+                                      data_types=self.ns_params.params_types,
+                                      ads_compatible=True)
+            ns_params = rf.NetworkSet.from_mdif(func(test_file))
+            self.assertEqual(ns_params, self.ns_params)
+
+            # with parameters and passing explicitly values and types and ads_compatible
+            self.ns_params.write_mdif(func(test_file),
+                                      values=self.ns_params.params_values,
+                                      data_types=self.ns_params.params_types,
+                                      ads_compatible=True)
+            ns_params = rf.NetworkSet.from_mdif(func(test_file))
+            self.assertEqual(ns_params, self.ns_params)
 
-        # with parameters and passing explicitly values and types
-        self.ns_params.write_mdif(test_file,
-                                  values=self.ns_params.params_values,
-                                  data_types=self.ns_params.params_types)
-        ns_params = rf.NetworkSet.from_mdif(test_file)
-        self.assertEqual(ns_params, self.ns_params)
         os.remove(test_file)
 
     def test_from_citi(self):
@@ -411,5 +442,8 @@ class NetworkSetTestCase(unittest.TestCase):
             print(citi_file)
             self.assertIsInstance(rf.NetworkSet.from_citi(citi_file), rf.NetworkSet)
 
+            # With Path object
+            self.assertIsInstance(rf.NetworkSet.from_citi(Path(citi_file)), rf.NetworkSet)
+
 suite = unittest.TestLoader().loadTestsFromTestCase(NetworkSetTestCase)
 unittest.TextTestRunner(verbosity=2).run(suite)
